@@ -1,5 +1,5 @@
 /*============================================================================
-Copyright (c) 2022-2025 Raspberry Pi Holdings Ltd.
+Copyright (c) 2022-2025 Raspberry Pi
 All rights reserved.
 
 Some code taken from the lxpanel project
@@ -67,6 +67,13 @@ extern void gtk_run (void);
 /* Global data                                                                */
 /*----------------------------------------------------------------------------*/
 
+conf_table_t conf_table[4] = {
+    {CONF_TYPE_INT,  "padding",          N_("Icon horizontal padding"),     NULL},
+    {CONF_TYPE_BOOL, "search_fixed",     N_("Fix height of search window"), NULL},
+    {CONF_TYPE_INT,  "search_height",    N_("Search window height"),        NULL},
+    {CONF_TYPE_NONE, NULL,               NULL,                              NULL}
+};
+
 static gboolean longpress;
 
 GQuark sys_menu_item_quark = 0;
@@ -622,24 +629,24 @@ static GtkWidget *create_system_menu_item (MenuCacheItem *item, MenuPlugin *m)
         if (icon_name)
         {
             if (strstr (icon_name, "/"))
-                icon = gdk_pixbuf_new_from_file_at_size (icon_name, m->icon_size, m->icon_size, NULL);
+                icon = gdk_pixbuf_new_from_file_at_size (icon_name, get_icon_size (), get_icon_size (), NULL);
             else
             {
                 icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), icon_name,
-                    m->icon_size, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
+                    get_icon_size (), GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
 
                 // fallback for packages using obsolete icon location
                 if (!icon)
                 {
                     char *fname = g_strdup_printf ("/usr/share/pixmaps/%s", icon_name);
-                    icon = gdk_pixbuf_new_from_file_at_size (fname, m->icon_size, m->icon_size, NULL);
+                    icon = gdk_pixbuf_new_from_file_at_size (fname, get_icon_size (), get_icon_size (), NULL);
                     g_free (fname);
                 }
             }
         }
         if (!icon)
             icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), "application-x-executable",
-                m->icon_size, GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
+                get_icon_size (), GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
         if (icon) gtk_image_set_from_pixbuf (GTK_IMAGE (img), icon);
 #endif
         if (menu_cache_item_get_type (item) == MENU_CACHE_TYPE_APP)
@@ -937,11 +944,17 @@ void menu_update_display (MenuPlugin *m)
 }
 
 /* Handler for control message */
-void menu_show_menu (MenuPlugin *m)
+gboolean menu_control_msg (MenuPlugin *m, const char *cmd)
 {
-    if (gtk_widget_is_visible (m->menu)) gtk_menu_popdown (GTK_MENU (m->menu));
-    else if (m->swin && gtk_widget_is_visible (m->swin)) destroy_search (m);
-    else wrap_show_menu (m->plugin, m->menu);
+    if (!strncmp (cmd, "menu", 4))
+    {
+        if (gtk_widget_is_visible (m->menu)) gtk_menu_popdown (GTK_MENU (m->menu));
+        else if (m->swin && gtk_widget_is_visible (m->swin)) destroy_search (m);
+        else wrap_show_menu (m->plugin, m->menu);
+        return TRUE;
+    }
+
+    return FALSE;
 }
 
 /* Handler for padding update from variable watcher */
@@ -1034,10 +1047,16 @@ static GtkWidget *menu_constructor (LXPanel *panel, config_setting_t *settings)
     m->plugin = gtk_button_new ();
     lxpanel_plugin_set_data (m->plugin, m, menu_destructor);
 
+    /* Set config defaults */
+    m->padding = 6;
+    m->fixed = FALSE;
+    m->height = 300;
+
     /* Read config */
-    if (!config_setting_lookup_int (m->settings, "padding", &m->padding)) m->padding = 4;
-    if (!config_setting_lookup_int (m->settings, "fixed", &m->fixed)) m->fixed = FALSE;
-    if (!config_setting_lookup_int (m->settings, "height", &m->height)) m->height = 300;
+    conf_table[0].value = (void *) &m->padding;
+    conf_table[1].value = (void *) &m->fixed;
+    conf_table[2].value = (void *) &m->height;
+    lxplug_read_settings (m->settings, conf_table);
 
     menu_init (m);
 
@@ -1064,10 +1083,10 @@ static void menu_panel_configuration_changed (LXPanel *, GtkWidget *plugin)
 }
 
 /* Handler for control message */
-static void menu_control (GtkWidget *plugin)
+static gboolean menu_control (GtkWidget *plugin, const char *cmd)
 {
     MenuPlugin *m = lxpanel_plugin_get_data (plugin);
-    menu_show_menu (m);
+    return menu_control_msg (m, cmd);
 }
 
 /* Apply changes from config dialog */
@@ -1075,9 +1094,7 @@ static gboolean menu_apply_config (gpointer user_data)
 {
     MenuPlugin *m = lxpanel_plugin_get_data (GTK_WIDGET (user_data));
 
-    config_group_set_int (m->settings, "padding", m->padding);
-    config_group_set_int (m->settings, "fixed", m->fixed);
-    config_group_set_int (m->settings, "height", m->height);
+    lxplug_write_settings (m->settings, conf_table);
 
     menu_set_padding (m);
     return FALSE;
@@ -1086,26 +1103,23 @@ static gboolean menu_apply_config (gpointer user_data)
 /* Display configuration dialog */
 static GtkWidget *menu_configure (LXPanel *panel, GtkWidget *plugin)
 {
-    MenuPlugin *m = lxpanel_plugin_get_data (plugin);
-
-    return lxpanel_generic_config_dlg (_("Menu"), panel, menu_apply_config, plugin,
-                                       _("Icon horizontal padding"), &m->padding, CONF_TYPE_INT,
-                                       _("Fix height of search window"), &m->fixed, CONF_TYPE_BOOL,
-                                       _("Search window height"), &m->height, CONF_TYPE_INT,
-                                       NULL);
+    return lxpanel_generic_config_dlg_new (_(PLUGIN_TITLE), panel,
+        menu_apply_config, plugin,
+        conf_table);
 }
 
-FM_DEFINE_MODULE (lxpanel_gtk, smenu)
+int module_lxpanel_gtk_version = 1;
+char module_name[] = PLUGIN_NAME;
 
 /* Plugin descriptor */
 LXPanelPluginInit fm_module_init_lxpanel_gtk = {
-    .name = N_("Menu with Search"),
+    .name = PLUGIN_TITLE,
     .description = N_("Searchable Application Menu"),
     .new_instance = menu_constructor,
     .reconfigure = menu_panel_configuration_changed,
     .config = menu_configure,
     .button_press_event = menu_button_press_event,
-    .show_system_menu = menu_control,
+    .control = menu_control,
     .gettext_package = GETTEXT_PACKAGE
 };
 #endif
